@@ -14,13 +14,14 @@
 #    under the License.
 
 import logging
+import queue
 import threading
 import time
 import uuid
 
 import cachetools
+from oslo_utils import eventletutils
 from oslo_utils import timeutils
-from six import moves
 
 import oslo_messaging
 from oslo_messaging._drivers import amqp as rpc_amqp
@@ -44,11 +45,12 @@ class MessageOperationsHandler(object):
     serialized and run in the same thread, since underlying drivers like kombu
     are not thread safe.
     """
+
     def __init__(self, name):
         self.name = "%s (%s)" % (name, hex(id(self)))
-        self._tasks = moves.queue.Queue()
+        self._tasks = queue.Queue()
 
-        self._shutdown = threading.Event()
+        self._shutdown = eventletutils.Event()
         self._shutdown_thread = threading.Thread(
             target=self._process_in_background)
         self._shutdown_thread.daemon = True
@@ -73,7 +75,7 @@ class MessageOperationsHandler(object):
         while True:
             try:
                 task = self._tasks.get(block=False)
-            except moves.queue.Empty:
+            except queue.Empty:
                 break
             task()
 
@@ -149,7 +151,7 @@ class AMQPIncomingMessage(base.RpcIncomingMessage):
             except rpc_amqp.AMQPDestinationNotFound:
                 if timer.check_return() > 0:
                     LOG.debug(("The reply %(msg_id)s cannot be sent  "
-                               "%(reply_q)s reply queue don't exist, "
+                               "%(reply_q)s reply queue doesn't exist, "
                                "retrying..."), {
                                    'msg_id': self.msg_id,
                                    'reply_q': self.reply_q})
@@ -218,7 +220,7 @@ class NotificationAMQPIncomingMessage(AMQPIncomingMessage):
 
 
 class ObsoleteReplyQueuesCache(object):
-    """Cache of reply queue id that doesn't exists anymore.
+    """Cache of reply queue id that doesn't exist anymore.
 
     NOTE(sileht): In case of a broker restart/failover
     a reply queue can be unreachable for short period
@@ -257,7 +259,7 @@ class ObsoleteReplyQueuesCache(object):
         self._no_reply_log(reply_q, msg_id)
 
     def _no_reply_log(self, reply_q, msg_id):
-        LOG.warning("%(reply_queue)s doesn't exists, drop reply to "
+        LOG.warning("%(reply_queue)s doesn't exist, drop reply to "
                     "%(msg_id)s", {'reply_queue': reply_q, "msg_id": msg_id})
 
 
@@ -269,8 +271,8 @@ class AMQPListener(base.PollStyleListener):
         self.conn = conn
         self.msg_id_cache = rpc_amqp._MsgIdCache()
         self.incoming = []
-        self._shutdown = threading.Event()
-        self._shutoff = threading.Event()
+        self._shutdown = eventletutils.Event()
+        self._shutoff = eventletutils.Event()
         self._obsolete_reply_queues = ObsoleteReplyQueuesCache()
         self._message_operations_handler = MessageOperationsHandler(
             "AMQPListener")
@@ -303,8 +305,11 @@ class AMQPListener(base.PollStyleListener):
 
         while not self._shutdown.is_set():
             self._message_operations_handler.process()
+            LOG.debug("Listener is running")
 
             if self.incoming:
+                LOG.debug("Poll the incoming message with unique_id: %s",
+                          self.incoming[0].unique_id)
                 return self.incoming.pop(0)
 
             left = stopwatch.leftover(return_none=True)
@@ -314,8 +319,10 @@ class AMQPListener(base.PollStyleListener):
                 return None
 
             try:
+                LOG.debug("AMQPListener connection consume")
                 self.conn.consume(timeout=min(self._current_timeout, left))
             except rpc_common.Timeout:
+                LOG.debug("AMQPListener connection timeout")
                 self._current_timeout = max(self._current_timeout * 2,
                                             ACK_REQUEUE_EVERY_SECONDS_MAX)
             else:
@@ -323,8 +330,11 @@ class AMQPListener(base.PollStyleListener):
 
         # NOTE(sileht): listener is stopped, just processes remaining messages
         # and operations
+        LOG.debug("Listener is stopped")
         self._message_operations_handler.process()
         if self.incoming:
+            LOG.debug("Poll the incoming message with unique_id: %s",
+                      self.incoming[0].unique_id)
             return self.incoming.pop(0)
 
         self._shutoff.set()
@@ -386,8 +396,6 @@ class NotificationAMQPListener(AMQPListener):
 
 class ReplyWaiters(object):
 
-    WAKE_UP = object()
-
     def __init__(self):
         self._queues = {}
         self._wrn_threshold = 10
@@ -395,7 +403,7 @@ class ReplyWaiters(object):
     def get(self, msg_id, timeout):
         try:
             return self._queues[msg_id].get(block=True, timeout=timeout)
-        except moves.queue.Empty:
+        except queue.Empty:
             raise oslo_messaging.MessagingTimeout(
                 'Timed out waiting for a reply '
                 'to message ID %s' % msg_id)
@@ -410,7 +418,7 @@ class ReplyWaiters(object):
             queue.put(message_data)
 
     def add(self, msg_id):
-        self._queues[msg_id] = moves.queue.Queue()
+        self._queues[msg_id] = queue.Queue()
         queues_length = len(self._queues)
         if queues_length > self._wrn_threshold:
             LOG.warning('Number of call queues is %(queues_length)s, '
@@ -435,7 +443,7 @@ class ReplyWaiter(object):
 
         self.conn.declare_direct_consumer(reply_q, self)
 
-        self._thread_exit_event = threading.Event()
+        self._thread_exit_event = eventletutils.Event()
         self._thread = threading.Thread(target=self.poll)
         self._thread.daemon = True
         self._thread.start()
@@ -521,7 +529,7 @@ class ReplyWaiter(object):
                     timeout = cm_timeout
             try:
                 message = self.waiters.get(msg_id, timeout=timeout)
-            except moves.queue.Empty:
+            except queue.Empty:
                 self._raise_timeout_exception(msg_id)
 
             reply, ending = self._process_reply(message)
